IPython Cluster Plugin — StarCluster v0.92.1 documentation

### Navigation

- index
- next |
- previous |
- Home »
- Master Table of Contents »
- Plugin Documentation »

# IPython Cluster Plugin

To configure your cluster as an interactive IPython cluster use the ipcluster plugin:

    [plugin ipcluster]
    setup_class = starcluster.plugins.ipcluster.IPCluster

The next step is to put the ipcluster plugin in the list of plugins in one of your cluster templates:

    [cluster smallcluster]
    ...
    plugins = ipcluster
    ...

### Navigation

- index
- next |
- previous |
- Home »
- Master Table of Contents »
- Plugin Documentation »